import React, { FC } from 'react';
import { Grid, Typography, Hidden } from '@material-ui/core';
import AddIcon from '@material-ui/icons/Add';
import Fab from '@material-ui/core/Fab';
import { NavBar } from 'components/Dashboard/HomePage/NavBar';
import { reservationPageStyle } from './ReservationPage.style';
import { ReservationDialog } from './ReservationDialog';
import { ReservationListViewer } from './ReservationListViewer';

export const ReservationPage: FC = () => {
  const classes = reservationPageStyle();

  const [isOpen, setIsOpen] = React.useState<boolean>(false);

  const handleOpen = (): void => {
    setIsOpen(true);
  };

  const handleClose = (): void => {
    setIsOpen(false);
  };

  return (
    <div data-testid="Reservation">
      <Grid container direction="column" className={classes.paddingBottom}>
        <div className={classes.root}>
          <Grid item>
            <NavBar />
          </Grid>
          <ReservationDialog handleClose={handleClose} isOpen={isOpen} />
          <header>
            <Grid item container className={classes.paddingBottom}>
              <Grid item xs={1} md={2} lg={2} />

              <Grid item xs={10} md={6} lg={4}>
                <Typography variant="h2" className={classes.whiteText}>
                  Plan Here Your
                </Typography>
                <Typography variant="h2" className={classes.whiteText}>
                  RESERVATIONS
                </Typography>
              </Grid>

              <Grid item xs={1} />
            </Grid>
          </header>
        </div>

        <Hidden smDown>
          <Fab
            color="primary"
            size="large"
            className={classes.fab}
            onClick={handleOpen}
            aria-label="Add New Reservations"
          >
            <AddIcon className={classes.extendedIcon} />
          </Fab>
        </Hidden>

        <Hidden mdUp>
          <Fab
            color="primary"
            size="large"
            aria-label="add"
            className={classes.fabSmall}
            onClick={handleOpen}
          >
            <AddIcon className={classes.extendedIcon} />
          </Fab>
        </Hidden>

        <Grid item container className={classes.paddingTop}>
          <Grid item xs={1} lg={2} />
          <Grid item xs={10} lg={8}>
            <Typography variant="h3">Your Next Reservations</Typography>
          </Grid>
          <Grid item xs={1} lg={2} />

          <Grid item xs={1} lg={2} />
          <Grid item xs={10} lg={8}>
            <ReservationListViewer />
          </Grid>
          <Grid item xs={1} lg={2} />
        </Grid>
      </Grid>
    </div>
  );
};
